static struct nxm_field_index all_nxm_fields[] = {
{ .nf = { NXM_HEADER(0x2320,0xffff,0,0,8), 0, "NXOXM_ET_DP_HASH", MFF_DP_HASH } },
{ .nf = { NXM_HEADER(0x0,0x1,35,0,4), 0, "NXM_NX_DP_HASH", MFF_DP_HASH } },
{ .nf = { NXM_HEADER(0x0,0x1,36,0,4), 0, "NXM_NX_RECIRC_ID", MFF_RECIRC_ID } },
{ .nf = { NXM_HEADER(0x0,0x8000,44,0,4), 6, "OXM_OF_PACKET_TYPE", MFF_PACKET_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x1,37,0,4), 0, "NXM_NX_CONJ_ID", MFF_CONJ_ID } },
{ .nf = { NXM_HEADER(0x0,0x1,16,0,8), 0, "NXM_NX_TUN_ID", MFF_TUN_ID } },
{ .nf = { NXM_HEADER(0x0,0x8000,38,0,8), 4, "OXM_OF_TUNNEL_ID", MFF_TUN_ID } },
{ .nf = { NXM_HEADER(0x0,0x1,31,0,4), 0, "NXM_NX_TUN_IPV4_SRC", MFF_TUN_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,32,0,4), 0, "NXM_NX_TUN_IPV4_DST", MFF_TUN_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,109,0,16), 0, "NXM_NX_TUN_IPV6_SRC", MFF_TUN_IPV6_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,110,0,16), 0, "NXM_NX_TUN_IPV6_DST", MFF_TUN_IPV6_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,104,0,2), 0, "NXM_NX_TUN_FLAGS", MFF_TUN_FLAGS } },
{ .nf = { NXM_HEADER(0x0,0x1,38,0,2), 0, "NXM_NX_TUN_GBP_ID", MFF_TUN_GBP_ID } },
{ .nf = { NXM_HEADER(0x0,0x1,39,0,1), 0, "NXM_NX_TUN_GBP_FLAGS", MFF_TUN_GBP_FLAGS } },
{ .nf = { NXM_HEADER(0x2320,0xffff,11,0,8), 0, "NXOXM_ET_ERSPAN_IDX", MFF_TUN_ERSPAN_IDX } },
{ .nf = { NXM_HEADER(0x2320,0xffff,12,0,5), 0, "NXOXM_ET_ERSPAN_VER", MFF_TUN_ERSPAN_VER } },
{ .nf = { NXM_HEADER(0x2320,0xffff,13,0,5), 0, "NXOXM_ET_ERSPAN_DIR", MFF_TUN_ERSPAN_DIR } },
{ .nf = { NXM_HEADER(0x2320,0xffff,14,0,5), 0, "NXOXM_ET_ERSPAN_HWID", MFF_TUN_ERSPAN_HWID } },
{ .nf = { NXM_HEADER(0x2320,0xffff,15,0,5), 0, "NXOXM_ET_GTPU_FLAGS", MFF_TUN_GTPU_FLAGS } },
{ .nf = { NXM_HEADER(0x2320,0xffff,16,0,5), 0, "NXOXM_ET_GTPU_MSGTYPE", MFF_TUN_GTPU_MSGTYPE } },
{ .nf = { NXM_HEADER(0x0,0x1,40,0,124), 0, "NXM_NX_TUN_METADATA0", MFF_TUN_METADATA0 } },
{ .nf = { NXM_HEADER(0x0,0x1,41,0,124), 0, "NXM_NX_TUN_METADATA1", MFF_TUN_METADATA1 } },
{ .nf = { NXM_HEADER(0x0,0x1,42,0,124), 0, "NXM_NX_TUN_METADATA2", MFF_TUN_METADATA2 } },
{ .nf = { NXM_HEADER(0x0,0x1,43,0,124), 0, "NXM_NX_TUN_METADATA3", MFF_TUN_METADATA3 } },
{ .nf = { NXM_HEADER(0x0,0x1,44,0,124), 0, "NXM_NX_TUN_METADATA4", MFF_TUN_METADATA4 } },
{ .nf = { NXM_HEADER(0x0,0x1,45,0,124), 0, "NXM_NX_TUN_METADATA5", MFF_TUN_METADATA5 } },
{ .nf = { NXM_HEADER(0x0,0x1,46,0,124), 0, "NXM_NX_TUN_METADATA6", MFF_TUN_METADATA6 } },
{ .nf = { NXM_HEADER(0x0,0x1,47,0,124), 0, "NXM_NX_TUN_METADATA7", MFF_TUN_METADATA7 } },
{ .nf = { NXM_HEADER(0x0,0x1,48,0,124), 0, "NXM_NX_TUN_METADATA8", MFF_TUN_METADATA8 } },
{ .nf = { NXM_HEADER(0x0,0x1,49,0,124), 0, "NXM_NX_TUN_METADATA9", MFF_TUN_METADATA9 } },
{ .nf = { NXM_HEADER(0x0,0x1,50,0,124), 0, "NXM_NX_TUN_METADATA10", MFF_TUN_METADATA10 } },
{ .nf = { NXM_HEADER(0x0,0x1,51,0,124), 0, "NXM_NX_TUN_METADATA11", MFF_TUN_METADATA11 } },
{ .nf = { NXM_HEADER(0x0,0x1,52,0,124), 0, "NXM_NX_TUN_METADATA12", MFF_TUN_METADATA12 } },
{ .nf = { NXM_HEADER(0x0,0x1,53,0,124), 0, "NXM_NX_TUN_METADATA13", MFF_TUN_METADATA13 } },
{ .nf = { NXM_HEADER(0x0,0x1,54,0,124), 0, "NXM_NX_TUN_METADATA14", MFF_TUN_METADATA14 } },
{ .nf = { NXM_HEADER(0x0,0x1,55,0,124), 0, "NXM_NX_TUN_METADATA15", MFF_TUN_METADATA15 } },
{ .nf = { NXM_HEADER(0x0,0x1,56,0,124), 0, "NXM_NX_TUN_METADATA16", MFF_TUN_METADATA16 } },
{ .nf = { NXM_HEADER(0x0,0x1,57,0,124), 0, "NXM_NX_TUN_METADATA17", MFF_TUN_METADATA17 } },
{ .nf = { NXM_HEADER(0x0,0x1,58,0,124), 0, "NXM_NX_TUN_METADATA18", MFF_TUN_METADATA18 } },
{ .nf = { NXM_HEADER(0x0,0x1,59,0,124), 0, "NXM_NX_TUN_METADATA19", MFF_TUN_METADATA19 } },
{ .nf = { NXM_HEADER(0x0,0x1,60,0,124), 0, "NXM_NX_TUN_METADATA20", MFF_TUN_METADATA20 } },
{ .nf = { NXM_HEADER(0x0,0x1,61,0,124), 0, "NXM_NX_TUN_METADATA21", MFF_TUN_METADATA21 } },
{ .nf = { NXM_HEADER(0x0,0x1,62,0,124), 0, "NXM_NX_TUN_METADATA22", MFF_TUN_METADATA22 } },
{ .nf = { NXM_HEADER(0x0,0x1,63,0,124), 0, "NXM_NX_TUN_METADATA23", MFF_TUN_METADATA23 } },
{ .nf = { NXM_HEADER(0x0,0x1,64,0,124), 0, "NXM_NX_TUN_METADATA24", MFF_TUN_METADATA24 } },
{ .nf = { NXM_HEADER(0x0,0x1,65,0,124), 0, "NXM_NX_TUN_METADATA25", MFF_TUN_METADATA25 } },
{ .nf = { NXM_HEADER(0x0,0x1,66,0,124), 0, "NXM_NX_TUN_METADATA26", MFF_TUN_METADATA26 } },
{ .nf = { NXM_HEADER(0x0,0x1,67,0,124), 0, "NXM_NX_TUN_METADATA27", MFF_TUN_METADATA27 } },
{ .nf = { NXM_HEADER(0x0,0x1,68,0,124), 0, "NXM_NX_TUN_METADATA28", MFF_TUN_METADATA28 } },
{ .nf = { NXM_HEADER(0x0,0x1,69,0,124), 0, "NXM_NX_TUN_METADATA29", MFF_TUN_METADATA29 } },
{ .nf = { NXM_HEADER(0x0,0x1,70,0,124), 0, "NXM_NX_TUN_METADATA30", MFF_TUN_METADATA30 } },
{ .nf = { NXM_HEADER(0x0,0x1,71,0,124), 0, "NXM_NX_TUN_METADATA31", MFF_TUN_METADATA31 } },
{ .nf = { NXM_HEADER(0x0,0x1,72,0,124), 0, "NXM_NX_TUN_METADATA32", MFF_TUN_METADATA32 } },
{ .nf = { NXM_HEADER(0x0,0x1,73,0,124), 0, "NXM_NX_TUN_METADATA33", MFF_TUN_METADATA33 } },
{ .nf = { NXM_HEADER(0x0,0x1,74,0,124), 0, "NXM_NX_TUN_METADATA34", MFF_TUN_METADATA34 } },
{ .nf = { NXM_HEADER(0x0,0x1,75,0,124), 0, "NXM_NX_TUN_METADATA35", MFF_TUN_METADATA35 } },
{ .nf = { NXM_HEADER(0x0,0x1,76,0,124), 0, "NXM_NX_TUN_METADATA36", MFF_TUN_METADATA36 } },
{ .nf = { NXM_HEADER(0x0,0x1,77,0,124), 0, "NXM_NX_TUN_METADATA37", MFF_TUN_METADATA37 } },
{ .nf = { NXM_HEADER(0x0,0x1,78,0,124), 0, "NXM_NX_TUN_METADATA38", MFF_TUN_METADATA38 } },
{ .nf = { NXM_HEADER(0x0,0x1,79,0,124), 0, "NXM_NX_TUN_METADATA39", MFF_TUN_METADATA39 } },
{ .nf = { NXM_HEADER(0x0,0x1,80,0,124), 0, "NXM_NX_TUN_METADATA40", MFF_TUN_METADATA40 } },
{ .nf = { NXM_HEADER(0x0,0x1,81,0,124), 0, "NXM_NX_TUN_METADATA41", MFF_TUN_METADATA41 } },
{ .nf = { NXM_HEADER(0x0,0x1,82,0,124), 0, "NXM_NX_TUN_METADATA42", MFF_TUN_METADATA42 } },
{ .nf = { NXM_HEADER(0x0,0x1,83,0,124), 0, "NXM_NX_TUN_METADATA43", MFF_TUN_METADATA43 } },
{ .nf = { NXM_HEADER(0x0,0x1,84,0,124), 0, "NXM_NX_TUN_METADATA44", MFF_TUN_METADATA44 } },
{ .nf = { NXM_HEADER(0x0,0x1,85,0,124), 0, "NXM_NX_TUN_METADATA45", MFF_TUN_METADATA45 } },
{ .nf = { NXM_HEADER(0x0,0x1,86,0,124), 0, "NXM_NX_TUN_METADATA46", MFF_TUN_METADATA46 } },
{ .nf = { NXM_HEADER(0x0,0x1,87,0,124), 0, "NXM_NX_TUN_METADATA47", MFF_TUN_METADATA47 } },
{ .nf = { NXM_HEADER(0x0,0x1,88,0,124), 0, "NXM_NX_TUN_METADATA48", MFF_TUN_METADATA48 } },
{ .nf = { NXM_HEADER(0x0,0x1,89,0,124), 0, "NXM_NX_TUN_METADATA49", MFF_TUN_METADATA49 } },
{ .nf = { NXM_HEADER(0x0,0x1,90,0,124), 0, "NXM_NX_TUN_METADATA50", MFF_TUN_METADATA50 } },
{ .nf = { NXM_HEADER(0x0,0x1,91,0,124), 0, "NXM_NX_TUN_METADATA51", MFF_TUN_METADATA51 } },
{ .nf = { NXM_HEADER(0x0,0x1,92,0,124), 0, "NXM_NX_TUN_METADATA52", MFF_TUN_METADATA52 } },
{ .nf = { NXM_HEADER(0x0,0x1,93,0,124), 0, "NXM_NX_TUN_METADATA53", MFF_TUN_METADATA53 } },
{ .nf = { NXM_HEADER(0x0,0x1,94,0,124), 0, "NXM_NX_TUN_METADATA54", MFF_TUN_METADATA54 } },
{ .nf = { NXM_HEADER(0x0,0x1,95,0,124), 0, "NXM_NX_TUN_METADATA55", MFF_TUN_METADATA55 } },
{ .nf = { NXM_HEADER(0x0,0x1,96,0,124), 0, "NXM_NX_TUN_METADATA56", MFF_TUN_METADATA56 } },
{ .nf = { NXM_HEADER(0x0,0x1,97,0,124), 0, "NXM_NX_TUN_METADATA57", MFF_TUN_METADATA57 } },
{ .nf = { NXM_HEADER(0x0,0x1,98,0,124), 0, "NXM_NX_TUN_METADATA58", MFF_TUN_METADATA58 } },
{ .nf = { NXM_HEADER(0x0,0x1,99,0,124), 0, "NXM_NX_TUN_METADATA59", MFF_TUN_METADATA59 } },
{ .nf = { NXM_HEADER(0x0,0x1,100,0,124), 0, "NXM_NX_TUN_METADATA60", MFF_TUN_METADATA60 } },
{ .nf = { NXM_HEADER(0x0,0x1,101,0,124), 0, "NXM_NX_TUN_METADATA61", MFF_TUN_METADATA61 } },
{ .nf = { NXM_HEADER(0x0,0x1,102,0,124), 0, "NXM_NX_TUN_METADATA62", MFF_TUN_METADATA62 } },
{ .nf = { NXM_HEADER(0x0,0x1,103,0,124), 0, "NXM_NX_TUN_METADATA63", MFF_TUN_METADATA63 } },
{ .nf = { NXM_HEADER(0x0,0x8000,2,0,8), 3, "OXM_OF_METADATA", MFF_METADATA } },
{ .nf = { NXM_HEADER(0x0,0x0,0,0,2), 0, "NXM_OF_IN_PORT", MFF_IN_PORT } },
{ .nf = { NXM_HEADER(0x0,0x8000,0,0,4), 3, "OXM_OF_IN_PORT", MFF_IN_PORT_OXM } },
{ .nf = { NXM_HEADER(0x4f4e4600,0xffff,43,0,8), 4, "ONFOXM_ET_ACTSET_OUTPUT", MFF_ACTSET_OUTPUT } },
{ .nf = { NXM_HEADER(0x0,0x8000,43,0,4), 6, "OXM_OF_ACTSET_OUTPUT", MFF_ACTSET_OUTPUT } },
{ .nf = { NXM_HEADER(0x0,0x1,33,0,4), 0, "NXM_NX_PKT_MARK", MFF_PKT_MARK } },
{ .nf = { NXM_HEADER(0x0,0x1,105,0,4), 0, "NXM_NX_CT_STATE", MFF_CT_STATE } },
{ .nf = { NXM_HEADER(0x0,0x1,106,0,2), 0, "NXM_NX_CT_ZONE", MFF_CT_ZONE } },
{ .nf = { NXM_HEADER(0x0,0x1,107,0,4), 0, "NXM_NX_CT_MARK", MFF_CT_MARK } },
{ .nf = { NXM_HEADER(0x0,0x1,108,0,16), 0, "NXM_NX_CT_LABEL", MFF_CT_LABEL } },
{ .nf = { NXM_HEADER(0x0,0x1,119,0,1), 0, "NXM_NX_CT_NW_PROTO", MFF_CT_NW_PROTO } },
{ .nf = { NXM_HEADER(0x0,0x1,120,0,4), 0, "NXM_NX_CT_NW_SRC", MFF_CT_NW_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,121,0,4), 0, "NXM_NX_CT_NW_DST", MFF_CT_NW_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,122,0,16), 0, "NXM_NX_CT_IPV6_SRC", MFF_CT_IPV6_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,123,0,16), 0, "NXM_NX_CT_IPV6_DST", MFF_CT_IPV6_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,124,0,2), 0, "NXM_NX_CT_TP_SRC", MFF_CT_TP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,125,0,2), 0, "NXM_NX_CT_TP_DST", MFF_CT_TP_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,0,0,4), 0, "NXM_NX_REG0", MFF_REG0 } },
{ .nf = { NXM_HEADER(0x0,0x1,1,0,4), 0, "NXM_NX_REG1", MFF_REG1 } },
{ .nf = { NXM_HEADER(0x0,0x1,2,0,4), 0, "NXM_NX_REG2", MFF_REG2 } },
{ .nf = { NXM_HEADER(0x0,0x1,3,0,4), 0, "NXM_NX_REG3", MFF_REG3 } },
{ .nf = { NXM_HEADER(0x0,0x1,4,0,4), 0, "NXM_NX_REG4", MFF_REG4 } },
{ .nf = { NXM_HEADER(0x0,0x1,5,0,4), 0, "NXM_NX_REG5", MFF_REG5 } },
{ .nf = { NXM_HEADER(0x0,0x1,6,0,4), 0, "NXM_NX_REG6", MFF_REG6 } },
{ .nf = { NXM_HEADER(0x0,0x1,7,0,4), 0, "NXM_NX_REG7", MFF_REG7 } },
{ .nf = { NXM_HEADER(0x0,0x1,8,0,4), 0, "NXM_NX_REG8", MFF_REG8 } },
{ .nf = { NXM_HEADER(0x0,0x1,9,0,4), 0, "NXM_NX_REG9", MFF_REG9 } },
{ .nf = { NXM_HEADER(0x0,0x1,10,0,4), 0, "NXM_NX_REG10", MFF_REG10 } },
{ .nf = { NXM_HEADER(0x0,0x1,11,0,4), 0, "NXM_NX_REG11", MFF_REG11 } },
{ .nf = { NXM_HEADER(0x0,0x1,12,0,4), 0, "NXM_NX_REG12", MFF_REG12 } },
{ .nf = { NXM_HEADER(0x0,0x1,13,0,4), 0, "NXM_NX_REG13", MFF_REG13 } },
{ .nf = { NXM_HEADER(0x0,0x1,14,0,4), 0, "NXM_NX_REG14", MFF_REG14 } },
{ .nf = { NXM_HEADER(0x0,0x1,15,0,4), 0, "NXM_NX_REG15", MFF_REG15 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,17,0,8), 0, "NXOXM_ET_REG16", MFF_REG16 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,18,0,8), 0, "NXOXM_ET_REG17", MFF_REG17 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,19,0,8), 0, "NXOXM_ET_REG18", MFF_REG18 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,20,0,8), 0, "NXOXM_ET_REG19", MFF_REG19 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,21,0,8), 0, "NXOXM_ET_REG20", MFF_REG20 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,22,0,8), 0, "NXOXM_ET_REG21", MFF_REG21 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,23,0,8), 0, "NXOXM_ET_REG22", MFF_REG22 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,24,0,8), 0, "NXOXM_ET_REG23", MFF_REG23 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,25,0,8), 0, "NXOXM_ET_REG24", MFF_REG24 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,26,0,8), 0, "NXOXM_ET_REG25", MFF_REG25 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,27,0,8), 0, "NXOXM_ET_REG26", MFF_REG26 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,28,0,8), 0, "NXOXM_ET_REG27", MFF_REG27 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,29,0,8), 0, "NXOXM_ET_REG28", MFF_REG28 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,30,0,8), 0, "NXOXM_ET_REG29", MFF_REG29 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,31,0,8), 0, "NXOXM_ET_REG30", MFF_REG30 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,32,0,8), 0, "NXOXM_ET_REG31", MFF_REG31 } },
{ .nf = { NXM_HEADER(0x0,0x8001,0,0,8), 4, "OXM_OF_PKT_REG0", MFF_XREG0 } },
{ .nf = { NXM_HEADER(0x0,0x8001,1,0,8), 4, "OXM_OF_PKT_REG1", MFF_XREG1 } },
{ .nf = { NXM_HEADER(0x0,0x8001,2,0,8), 4, "OXM_OF_PKT_REG2", MFF_XREG2 } },
{ .nf = { NXM_HEADER(0x0,0x8001,3,0,8), 4, "OXM_OF_PKT_REG3", MFF_XREG3 } },
{ .nf = { NXM_HEADER(0x0,0x8001,4,0,8), 4, "OXM_OF_PKT_REG4", MFF_XREG4 } },
{ .nf = { NXM_HEADER(0x0,0x8001,5,0,8), 4, "OXM_OF_PKT_REG5", MFF_XREG5 } },
{ .nf = { NXM_HEADER(0x0,0x8001,6,0,8), 4, "OXM_OF_PKT_REG6", MFF_XREG6 } },
{ .nf = { NXM_HEADER(0x0,0x8001,7,0,8), 4, "OXM_OF_PKT_REG7", MFF_XREG7 } },
{ .nf = { NXM_HEADER(0x0,0x8001,8,0,8), 4, "OXM_OF_PKT_REG8", MFF_XREG8 } },
{ .nf = { NXM_HEADER(0x0,0x8001,9,0,8), 4, "OXM_OF_PKT_REG9", MFF_XREG9 } },
{ .nf = { NXM_HEADER(0x0,0x8001,10,0,8), 4, "OXM_OF_PKT_REG10", MFF_XREG10 } },
{ .nf = { NXM_HEADER(0x0,0x8001,11,0,8), 4, "OXM_OF_PKT_REG11", MFF_XREG11 } },
{ .nf = { NXM_HEADER(0x0,0x8001,12,0,8), 4, "OXM_OF_PKT_REG12", MFF_XREG12 } },
{ .nf = { NXM_HEADER(0x0,0x8001,13,0,8), 4, "OXM_OF_PKT_REG13", MFF_XREG13 } },
{ .nf = { NXM_HEADER(0x0,0x8001,14,0,8), 4, "OXM_OF_PKT_REG14", MFF_XREG14 } },
{ .nf = { NXM_HEADER(0x0,0x8001,15,0,8), 4, "OXM_OF_PKT_REG15", MFF_XREG15 } },
{ .nf = { NXM_HEADER(0x0,0x1,111,0,16), 0, "NXM_NX_XXREG0", MFF_XXREG0 } },
{ .nf = { NXM_HEADER(0x0,0x1,112,0,16), 0, "NXM_NX_XXREG1", MFF_XXREG1 } },
{ .nf = { NXM_HEADER(0x0,0x1,113,0,16), 0, "NXM_NX_XXREG2", MFF_XXREG2 } },
{ .nf = { NXM_HEADER(0x0,0x1,114,0,16), 0, "NXM_NX_XXREG3", MFF_XXREG3 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,33,0,20), 0, "NXOXM_ET_XXREG4", MFF_XXREG4 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,34,0,20), 0, "NXOXM_ET_XXREG5", MFF_XXREG5 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,35,0,20), 0, "NXOXM_ET_XXREG6", MFF_XXREG6 } },
{ .nf = { NXM_HEADER(0x2320,0xffff,36,0,20), 0, "NXOXM_ET_XXREG7", MFF_XXREG7 } },
{ .nf = { NXM_HEADER(0x0,0x0,2,0,6), 0, "NXM_OF_ETH_SRC", MFF_ETH_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,4,0,6), 3, "OXM_OF_ETH_SRC", MFF_ETH_SRC } },
{ .nf = { NXM_HEADER(0x0,0x0,1,0,6), 0, "NXM_OF_ETH_DST", MFF_ETH_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,3,0,6), 3, "OXM_OF_ETH_DST", MFF_ETH_DST } },
{ .nf = { NXM_HEADER(0x0,0x0,3,0,2), 0, "NXM_OF_ETH_TYPE", MFF_ETH_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x8000,5,0,2), 3, "OXM_OF_ETH_TYPE", MFF_ETH_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x0,4,0,2), 0, "NXM_OF_VLAN_TCI", MFF_VLAN_TCI } },
{ .nf = { NXM_HEADER(0x0,0x8000,6,0,2), 3, "OXM_OF_VLAN_VID", MFF_VLAN_VID } },
{ .nf = { NXM_HEADER(0x0,0x8000,7,0,1), 3, "OXM_OF_VLAN_PCP", MFF_VLAN_PCP } },
{ .nf = { NXM_HEADER(0x0,0x8000,34,0,4), 3, "OXM_OF_MPLS_LABEL", MFF_MPLS_LABEL } },
{ .nf = { NXM_HEADER(0x0,0x8000,35,0,1), 3, "OXM_OF_MPLS_TC", MFF_MPLS_TC } },
{ .nf = { NXM_HEADER(0x0,0x8000,36,0,1), 4, "OXM_OF_MPLS_BOS", MFF_MPLS_BOS } },
{ .nf = { NXM_HEADER(0x0,0x1,30,0,1), 0, "NXM_NX_MPLS_TTL", MFF_MPLS_TTL } },
{ .nf = { NXM_HEADER(0x0,0x0,7,0,4), 0, "NXM_OF_IP_SRC", MFF_IPV4_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,11,0,4), 3, "OXM_OF_IPV4_SRC", MFF_IPV4_SRC } },
{ .nf = { NXM_HEADER(0x0,0x0,8,0,4), 0, "NXM_OF_IP_DST", MFF_IPV4_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,12,0,4), 3, "OXM_OF_IPV4_DST", MFF_IPV4_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,19,0,16), 0, "NXM_NX_IPV6_SRC", MFF_IPV6_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,26,0,16), 3, "OXM_OF_IPV6_SRC", MFF_IPV6_SRC } },
{ .nf = { NXM_HEADER(0x0,0x1,20,0,16), 0, "NXM_NX_IPV6_DST", MFF_IPV6_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,27,0,16), 3, "OXM_OF_IPV6_DST", MFF_IPV6_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,27,0,4), 0, "NXM_NX_IPV6_LABEL", MFF_IPV6_LABEL } },
{ .nf = { NXM_HEADER(0x0,0x8000,28,0,4), 3, "OXM_OF_IPV6_FLABEL", MFF_IPV6_LABEL } },
{ .nf = { NXM_HEADER(0x0,0x0,6,0,1), 0, "NXM_OF_IP_PROTO", MFF_IP_PROTO } },
{ .nf = { NXM_HEADER(0x0,0x8000,10,0,1), 3, "OXM_OF_IP_PROTO", MFF_IP_PROTO } },
{ .nf = { NXM_HEADER(0x0,0x0,5,0,1), 0, "NXM_OF_IP_TOS", MFF_IP_DSCP } },
{ .nf = { NXM_HEADER(0x0,0x8000,8,0,1), 3, "OXM_OF_IP_DSCP", MFF_IP_DSCP_SHIFTED } },
{ .nf = { NXM_HEADER(0x0,0x1,28,0,1), 0, "NXM_NX_IP_ECN", MFF_IP_ECN } },
{ .nf = { NXM_HEADER(0x0,0x8000,9,0,1), 3, "OXM_OF_IP_ECN", MFF_IP_ECN } },
{ .nf = { NXM_HEADER(0x0,0x1,29,0,1), 0, "NXM_NX_IP_TTL", MFF_IP_TTL } },
{ .nf = { NXM_HEADER(0x0,0x1,26,0,1), 0, "NXM_NX_IP_FRAG", MFF_IP_FRAG } },
{ .nf = { NXM_HEADER(0x0,0x0,15,0,2), 0, "NXM_OF_ARP_OP", MFF_ARP_OP } },
{ .nf = { NXM_HEADER(0x0,0x8000,21,0,2), 3, "OXM_OF_ARP_OP", MFF_ARP_OP } },
{ .nf = { NXM_HEADER(0x0,0x0,16,0,4), 0, "NXM_OF_ARP_SPA", MFF_ARP_SPA } },
{ .nf = { NXM_HEADER(0x0,0x8000,22,0,4), 3, "OXM_OF_ARP_SPA", MFF_ARP_SPA } },
{ .nf = { NXM_HEADER(0x0,0x0,17,0,4), 0, "NXM_OF_ARP_TPA", MFF_ARP_TPA } },
{ .nf = { NXM_HEADER(0x0,0x8000,23,0,4), 3, "OXM_OF_ARP_TPA", MFF_ARP_TPA } },
{ .nf = { NXM_HEADER(0x0,0x1,17,0,6), 0, "NXM_NX_ARP_SHA", MFF_ARP_SHA } },
{ .nf = { NXM_HEADER(0x0,0x8000,24,0,6), 3, "OXM_OF_ARP_SHA", MFF_ARP_SHA } },
{ .nf = { NXM_HEADER(0x0,0x1,18,0,6), 0, "NXM_NX_ARP_THA", MFF_ARP_THA } },
{ .nf = { NXM_HEADER(0x0,0x8000,25,0,6), 3, "OXM_OF_ARP_THA", MFF_ARP_THA } },
{ .nf = { NXM_HEADER(0x0,0x0,9,0,2), 0, "NXM_OF_TCP_SRC", MFF_TCP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,13,0,2), 3, "OXM_OF_TCP_SRC", MFF_TCP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x0,10,0,2), 0, "NXM_OF_TCP_DST", MFF_TCP_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,14,0,2), 3, "OXM_OF_TCP_DST", MFF_TCP_DST } },
{ .nf = { NXM_HEADER(0x0,0x1,34,0,2), 0, "NXM_NX_TCP_FLAGS", MFF_TCP_FLAGS } },
{ .nf = { NXM_HEADER(0x4f4e4600,0xffff,42,0,6), 4, "ONFOXM_ET_TCP_FLAGS", MFF_TCP_FLAGS } },
{ .nf = { NXM_HEADER(0x0,0x8000,42,0,2), 6, "OXM_OF_TCP_FLAGS", MFF_TCP_FLAGS } },
{ .nf = { NXM_HEADER(0x0,0x0,11,0,2), 0, "NXM_OF_UDP_SRC", MFF_UDP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,15,0,2), 3, "OXM_OF_UDP_SRC", MFF_UDP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x0,12,0,2), 0, "NXM_OF_UDP_DST", MFF_UDP_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,16,0,2), 3, "OXM_OF_UDP_DST", MFF_UDP_DST } },
{ .nf = { NXM_HEADER(0x0,0x8000,17,0,2), 3, "OXM_OF_SCTP_SRC", MFF_SCTP_SRC } },
{ .nf = { NXM_HEADER(0x0,0x8000,18,0,2), 3, "OXM_OF_SCTP_DST", MFF_SCTP_DST } },
{ .nf = { NXM_HEADER(0x0,0x0,13,0,1), 0, "NXM_OF_ICMP_TYPE", MFF_ICMPV4_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x8000,19,0,1), 3, "OXM_OF_ICMPV4_TYPE", MFF_ICMPV4_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x0,14,0,1), 0, "NXM_OF_ICMP_CODE", MFF_ICMPV4_CODE } },
{ .nf = { NXM_HEADER(0x0,0x8000,20,0,1), 3, "OXM_OF_ICMPV4_CODE", MFF_ICMPV4_CODE } },
{ .nf = { NXM_HEADER(0x0,0x1,21,0,1), 0, "NXM_NX_ICMPV6_TYPE", MFF_ICMPV6_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x8000,29,0,1), 3, "OXM_OF_ICMPV6_TYPE", MFF_ICMPV6_TYPE } },
{ .nf = { NXM_HEADER(0x0,0x1,22,0,1), 0, "NXM_NX_ICMPV6_CODE", MFF_ICMPV6_CODE } },
{ .nf = { NXM_HEADER(0x0,0x8000,30,0,1), 3, "OXM_OF_ICMPV6_CODE", MFF_ICMPV6_CODE } },
{ .nf = { NXM_HEADER(0x0,0x1,23,0,16), 0, "NXM_NX_ND_TARGET", MFF_ND_TARGET } },
{ .nf = { NXM_HEADER(0x0,0x8000,31,0,16), 3, "OXM_OF_IPV6_ND_TARGET", MFF_ND_TARGET } },
{ .nf = { NXM_HEADER(0x0,0x1,24,0,6), 0, "NXM_NX_ND_SLL", MFF_ND_SLL } },
{ .nf = { NXM_HEADER(0x0,0x8000,32,0,6), 3, "OXM_OF_IPV6_ND_SLL", MFF_ND_SLL } },
{ .nf = { NXM_HEADER(0x0,0x1,25,0,6), 0, "NXM_NX_ND_TLL", MFF_ND_TLL } },
{ .nf = { NXM_HEADER(0x0,0x8000,33,0,6), 3, "OXM_OF_IPV6_ND_TLL", MFF_ND_TLL } },
{ .nf = { NXM_HEADER(0x0,0x1000,1,0,4), 0, "ERICOXM_OF_ICMPV6_ND_RESERVED", MFF_ND_RESERVED } },
{ .nf = { NXM_HEADER(0x0,0x1000,2,0,1), 0, "ERICOXM_OF_ICMPV6_ND_OPTIONS_TYPE", MFF_ND_OPTIONS_TYPE } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,1,0,5), 0, "NXOXM_NSH_FLAGS", MFF_NSH_FLAGS } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,2,0,5), 0, "NXOXM_NSH_MDTYPE", MFF_NSH_MDTYPE } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,3,0,5), 0, "NXOXM_NSH_NP", MFF_NSH_NP } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,4,0,8), 0, "NXOXM_NSH_SPI", MFF_NSH_SPI } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,5,0,5), 0, "NXOXM_NSH_SI", MFF_NSH_SI } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,6,0,8), 0, "NXOXM_NSH_C1", MFF_NSH_C1 } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,7,0,8), 0, "NXOXM_NSH_C2", MFF_NSH_C2 } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,8,0,8), 0, "NXOXM_NSH_C3", MFF_NSH_C3 } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,9,0,8), 0, "NXOXM_NSH_C4", MFF_NSH_C4 } },
{ .nf = { NXM_HEADER(0x5ad650,0xffff,10,0,5), 0, "NXOXM_NSH_TTL", MFF_NSH_TTL } },
};
/* Generated automatically; do not modify!    -*- buffer-read-only: t -*- */

